# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-26 06:10
from __future__ import unicode_literals

import django.core.files.storage
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0019_auto_20180125_1125'),
    ]

    operations = [
        migrations.AddField(
            model_name='grade',
            name='icon',
            field=models.ImageField(blank=True, null=True, storage=django.core.files.storage.FileSystemStorage(base_url='/media/exam/cert/icon', location='media/exam/cert/icon'), upload_to=b'', verbose_name='\u7ea7\u522b\u5c0f\u56fe\u6807'),
        ),
        migrations.AlterField(
            model_name='grade',
            name='cert_image',
            field=models.ImageField(blank=True, null=True, storage=django.core.files.storage.FileSystemStorage(base_url='/media/exam/cert/original', location='media/exam/cert/original'), upload_to=b'', verbose_name='\u8bc1\u4e66\u56fe\u7247'),
        ),
    ]
